### Name: aidsEst
### Title: Estimation of the Almost Ideal Demand System (AIDS)
### Aliases: aidsEst
### Keywords: models

### ** Examples

   # Using data published in Blanciforti, Green & King (1986)
   data( Blanciforti86 )
   # Data on food consumption are available only for the first 32 years
   Blanciforti86 <- Blanciforti86[ 1:32, ]

   ## Repeating the demand analysis of Blanciforti, Green & King (1986)
   estResult <- aidsEst( c( "pFood1", "pFood2", "pFood3", "pFood4" ),
      c( "wFood1", "wFood2", "wFood3", "wFood4" ), "xFood",
      data = Blanciforti86, method = "LA:SL", elaFormula = "Ch",
      maxiter = 1, rcovformula = 1, tol = 1e-7 )
   print( estResult )

   ## Repeating the evaluation of different elasticity formulas of
   ## Green & Alston (1990)
   pNames <- c( "pFood1", "pFood2", "pFood3", "pFood4" )
   wNames <- c( "wFood1", "wFood2", "wFood3", "wFood4" )

   # AIDS
   estResultA <- aidsEst( pNames, wNames, "xFood",
      data = Blanciforti86[ -1, ], maxiter = 1,
      elaFormula = "AIDS", rcovformula=1, tol=1e-7,
      method = "IL:L" )
   print( diag( estResultA$ela$marshall ) )

   # LA-AIDS + formula of AIDS
   estResultL1 <- aidsEst( pNames, wNames, "xFood",
      data = Blanciforti86, maxiter = 1, elaFormula = "AIDS",
      rcovformula=1, tol=1e-7, method = "LA:SL" )
   print( diag( estResultL1$ela$marshall ) )

   # LA-AIDS + formula of Eales + Unnevehr
   estResultL2 <- aidsEst( pNames, wNames, "xFood",
      data = Blanciforti86, maxiter = 1, elaFormula = "EU",
      rcovformula=1, tol=1e-7, method = "LA:SL" )
   print( diag( estResultL2$ela$marshall ) )

   # LA-AIDS + formula of Chalfant:
   estResultL3 <- aidsEst( pNames, wNames, "xFood",
      data = Blanciforti86, maxiter = 1, elaFormula = "Ch",
      rcovformula=1, tol=1e-7, method = "LA:SL" )
   print( diag( estResultL3$ela$marshall ) )



